<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	/**
	 * Handles display and processing for a Checkbox field.
	 * 
	 * There are no options for this field.
	 * 
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	class Checkbox extends FieldManager {
		/**
		 * Prepares this form field for display.
		 * 
		 * @param MIXED $defaultValue Null if the checkbox was not checked, some value if checked
		 * @param BOOLEAN $enabled True if this form field is editable
		 * @return STRING HTML to display for the form field
		 */
		function show($defaultValue, $enabled=true) {
			$ret = '<input type="checkbox" name="'.$this->getName().'"';
			if(!empty($defaultValue)) {
				$ret .= ' checked';
			}
			if(!$enabled) {
				$ret .= ' readonly';
			}
			$ret .= '>';
			
			$ret .= $this->getErrorText();
			return $ret;
		}
		
		/**
		 * Prepares this form field for display in a list.
		 * 
		 * @param MIXED $defaultValue Default value to display for this field in a list
		 * @return STRING HTML to display in a list view
		 */
		function showListView($defaultValue) {
			if(empty($defaultValue) || $defaultValue == 0) {
				return "";
			} else {
				//checkmark symbol
				return "&#10003;";
			}
		}
		
		/**
		 * Processes this field and returns formated data ready for insertion into a SQL database.
		 * 
		 * @param MIXED $value Value to process
		 * @param INTEGER $mode The type of this form (one of the form type constants defined in the Form class)
		 * @return STRING Formatted string ready for insertion into a SQL database
		 */
		function process($value, $mode) {
			if(empty($value)) {
				return '0';
			} else {
				return '1';
			}
		}
	}
?>