<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	/**
	 * Handles display and processing for a ForeignKey field.
	 * 
	 * A foreign key gets its value from a key field which must be processed before
	 * this field.
	 * $option = Instance of class Key
	 * 
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	class ForeignKey extends FieldManager {
		/**
		 * Prepares this form field for display.
		 * 
		 * @param STRING $defaultValue Default value to display in this form field
		 * @param BOOLEAN $enabled True if this form field is editable
		 * @return STRING HTML to display for the form field
		 */
		function show($defaultValue, $enabled=true) {
			$option = $this->getOptions();
			if(!($option instanceof Key)) {
				$this->error = "FATAL ERROR: Foreign Keys must have an object of type Key as their parameter";
			} else {
				$ret = '<input type="hidden" name="'.$this->getName().'" value="'.FieldManager::formPrep($option->getValue()).'">';
			}
			
			$ret .= $this->getErrorText();
			return $ret;
		}
		
		/**
		 * Processes this field and returns formated data ready for insertion into a SQL database.
		 * 
		 * @param STRING $value Value to process
		 * @param INTEGER $mode The type of this form (one of the form type constants defined in the Form class)
		 * @return STRING Formatted string ready for insertion into a SQL database
		 */
		function process($value, $mode) {
			$option = $this->getOptions();
			return FieldManager::SQLPrep($option->getValue());
		}
	}
?>