<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	/**
	 * Handles display and processing of a Key field.
	 * 
	 * A key field is like a hidden field, except that it can be used to populate a foreign key field.
	 * There are no options for this field.
	 * 
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	class Key extends FieldManager {
		/** @var The most recent value of this field. */
		private $value;
		
		/**
		 * Prepares this form field for display and stores the value being displayed.
		 * 
		 * @param STRING $defaultValue Default value to display in this form field
		 * @param BOOLEAN $enabled True if this form field is editable
		 * @return STRING HTML to display for the form field
		 */
		function show($defaultValue, $enabled=true) {
			$ret = '<input type="hidden" name="'.$this->getName().'" value="'.FieldManager::formPrep($defaultValue).'">';
			$this->value = $defaultValue;
			
			$ret .= $this->getErrorText();
			return $ret;
		}
		
		/**
		 * Processes this field, updates the current value field, and returns formated data ready for insertion into a SQL database.
		 * 
		 * @param STRING $value Value to process
		 * @param INTEGER $mode The type of this form (one of the form type constants defined in the Form class)
		 * @return STRING Formatted string ready for insertion into a SQL database
		 */
		function process($value, $mode) {
			$this->value = $value;
			return FieldManager::SQLPrep($value);
		}
		
		/**
		 * Returns the most recent value of this field.
		 * 
		 * @return STRING Value of this field.
		 */
		function getValue() {
			return $this->value;
		}
	}
?>