<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	/**
	 * Handles display and processing of a Select field.
	 * 
	 * The options parameter is an array of key-value pairs in the following format:
	 * $options[key] = value
	 * 
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	class Select extends FieldManager {
		/**
		 * Prepares this form field for display.
		 * 
		 * @param MIXED $defaultValue Default key value to use to display the correct option for this form field
		 * @param BOOLEAN $enabled True if this form field is editable
		 * @return STRING HTML to display for the form field
		 */
		function show($defaultValue, $enabled=true) {
			$values = $this->getOptions();
			$ret = '<select name="'.$this->getName().'"';
			if(!$enabled) {
				$ret .= ' readonly';
			}
			$ret .= '>';
			foreach($values as $key=>$val) {
				$ret .= '<option value="'.$key.'"';
				if($key == $defaultValue) {
					$ret .= ' selected';
				}
				$ret .= '>'.FieldManager::formPrep($val).'</option>';
			}
			$ret .= '</select>';
			
			$ret .= $this->getErrorText();
			return $ret;
		}
		
		/**
		 * Prepares this form field for display in a list.
		 * 
		 * @param MIXED $defaultValue Key for the option value to show in a list
		 * @return STRING HTML to display in a list view
		 */
		function showListView($defaultValue) {
			return $this->options[$defaultValue];
		}
		
		/**
		 * Processes this field and returns formated data ready for insertion into a SQL database.
		 * 
		 * @param MIXED $value Key value to process
		 * @param INTEGER $mode The type of this form (one of the form type constants defined in the Form class)
		 * @return STRING Formatted string ready for insertion into a SQL database
		 */
		function process($value, $mode) {
			return FieldManager::SQLPrep($value);
		}
	}
?>