<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	require_once($path."OpenSiteAdmin/scripts/classes/SecurityManager.php");
	
	/**
	 * Handles processing and security for the site's login process.
	 * 
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	class LoginManager {
		/**
		 * @static
		 * @final
		 * @var The maximum number of login attempts that can be made before a user's account is suspended.
		 */
		const MAX_LOGIN_ATTEMPTS = 5;
		
		/**
		 * @static
		 * @final
		 * @var Error code constant - no errors where encountered.
		 */
		const NONE = 0;
		/**
		 * @static
		 * @final
		 * @var Error code constant - an unknown error was encountered.
		 */
		const UNKNOWN = 1;
		/**
		 * @static
		 * @final
		 * @var Error code constant - the provided username and\or password was invalid.
		 */
		const INVALID = 2;
		/**
		 * @static
		 * @final
		 * @var Error code constant - The specified account has been suspended.
		 */
		const SUSPENDED = 3;
		
		/** @var DatabaseManager object. */
		private $SQL;
		
		/**
		 * Provides the class with a DatabaseManager object.
		 * 
		 * @param OBJECT $sql DatabaseManager object.
		 */
		function __construct($sql) {
			if(!($sql instanceof DatabaseManager)) {
				$error = "ERROR: Attempted to initiate a login request with a database connection $sql that does not inherit DatabaseManager";
				ErrorLogManager::log($error, ErrorLogManager::FATAL);
				die("A fatal error occured - Contact your System Administrator<br>This error has been logged");
			}
			
			$this->SQL = $sql;
		}
		
		/**
		 * Attempts to log a user into the site's administrative system.
		 * 
		 * @param STRING $user Username to use to login.
		 * @param STRING $pass Password to attempt to use with the given user.
		 * @param STRING $remember If set to "yes", the user's login information will be saved in cookies if it validates sucessfully.
		 * @param BOOLEAN $isCookie True if the provided data is coming from cookie data (cookie passwords are already encrypted).
		 * @return INTEGER One of the error code constants defined in this class.
		 */
		function login($user, $pass, $remember="no", $isCookie=false) {
			$sql = "select * from `users` where `username` = '$user'";
			$result = mysql_query($sql, $this->SQL->getLinkResource());
			if(mysql_num_rows($result) === 0) {
				return LoginManager::INVALID;
			}
			$row = mysql_fetch_assoc($result);
			if($row["active"] == "1") {
				if($isCookie) {
					$pass2 = SecurityManager::encrypt($row["password"]);
				} else {
					$pass2 = $row["password"];
				}
				if(SecurityManager::encrypt($pass) == $pass2) {
					$_SESSION["ID"] = $row["ID"];
					$_SESSION["username"] = $row["username"];
					$_SESSION["permissions"] = $row["permissions"];
					if($remember == "yes") {
						//60*60*24*365.25*8 = 8 years (the 0.25 takes leap years into account)
						setcookie( "username", $row["username"], time()+(60*60*24*365.25*8), "/", SITE_NAME);
						setcookie( "password", $row["password"], time()+(60*60*24*365.25*8), "/", SITE_NAME);
					}
					return LoginManager::NONE;
				} else {
					return LoginManager::INVALID;
				}
			} else {
				return LoginManager::SUSPENDED;
			}
			return LoginManager::UNKNOWN;
		}
		
		/**
		 * Attempts to suspend the account associated with the given username.
		 * 
		 * @param STRING $user Username for the account to suspend.
		 * @return VOID
		 */
		function suspend($user) {
			$sql = "select * from `users` where `username` = '$user'";
			$result = mysql_query($sql, $this->SQL->getLinkResource());
			if(mysql_num_rows($result) === 0) {
				return;
			}
			$row = mysql_fetch_assoc($result);
			$sql = "update `users` set `active` = '0' where `userID` = '".$row['usersID']."'";
			mysql_query($sql, $this->SQL->getLinkResource());
		}
	}
?>